==> haskell-hls-eval-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-eval-plugin-2.1.0.0-1HPbTcOfarZJXUzlmQG0WP
key:                  hls-eval-plugin-2.1.0.0-1HPbTcOfarZJXUzlmQG0WP
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e6cc278d25aef410cc3bb393dc588cea
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.1.0.0-1HPbTcOfarZJXUzlmQG0WP
depends:
    Diff-0.5-yETzKh0qtuDUuvJdOns8X
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9 mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    pretty-simple-4.1.3.0-FVwSxUgLrGFBqfQuiA3nvl
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-eval-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-eval-plugin-2.1.0.0-3niQ5sn35H3KrDeafBPoSi
key:                  hls-eval-plugin-2.1.0.0-3niQ5sn35H3KrDeafBPoSi
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  0680a3fa273b74f8366fda26654b19d1
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.1.0.0-3niQ5sn35H3KrDeafBPoSi
depends:
    Diff-0.5-8gj4s2z6jOl7FPRCGftIez
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hls-graph-2.1.0.0-LgEicARMXCt6QmF6Vp3LRx
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    pretty-simple-4.1.4.0-L06q4MjGm0c3vpgIEWeUpU
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
